import * as dynamodb from '@aws-cdk/aws-dynamodb';
import { Schedule } from '@aws-cdk/aws-events';
import { Stream } from '@aws-cdk/aws-kinesis';
import * as kms from '@aws-cdk/aws-kms';
import * as cdk from '@aws-cdk/core';
/**
 * @stability stable
 */
export interface ICompliantDynamoDbProps {
    /**
     * @stability stable
     */
    readonly partitionKey?: dynamodb.Attribute;
    /**
     * @stability stable
     */
    readonly sortKey?: dynamodb.Attribute;
    /**
     * @stability stable
     */
    readonly tableName?: string;
    /**
     * @stability stable
     */
    readonly encryptionKey?: kms.Key;
    /**
     * @stability stable
     */
    readonly contributorInsightsEnabled?: boolean;
    /**
     * @stability stable
     */
    readonly backupVaultName?: string;
    /**
     * @stability stable
     */
    readonly backupPlanStartTime?: Schedule;
    /**
     * @stability stable
     */
    readonly kinesisStream?: Stream;
    /**
     * @stability stable
     */
    readonly replicationRegions?: string[];
    /**
     * @stability stable
     */
    readonly replicationTimeout?: cdk.Duration;
    /**
     * @stability stable
     */
    readonly timeToLiveAttribute?: string;
}
/**
 * Creates a DynamoDB table that is secured by an AWS backup plan und with point in time recovery enabled by default.
 *
 * @stability stable
 */
export declare class CompliantDynamoDb extends cdk.Construct {
    /**
     * @stability stable
     */
    readonly dynamodbTable: dynamodb.Table;
    /**
     * @stability stable
     */
    constructor(scope: cdk.Construct, id: string, props?: ICompliantDynamoDbProps);
}
